searchData={"items":[{"type":"module","title":"PipelineFlow","doc":"Module to formalize flow","ref":"PipelineFlow.html"},{"type":"module","title":"Examples - PipelineFlow","doc":"```elixir\ndefmodule OrderFlow do\n  use PipelineFlow\n\n  attributes reference: nil,\n    items: []\nend\n```","ref":"PipelineFlow.html#module-examples"},{"type":"macro","title":"PipelineFlow.attrs/1","doc":"Defines struct for PipelineFlow module","ref":"PipelineFlow.html#attrs/1"},{"type":"macro","title":"PipelineFlow.step/2","doc":"Defines a step","ref":"PipelineFlow.html#step/2"},{"type":"macro","title":"PipelineFlow.step/3","doc":"","ref":"PipelineFlow.html#step/3"},{"type":"type","title":"PipelineFlow.pipeline/0","doc":"","ref":"PipelineFlow.html#t:pipeline/0"},{"type":"type","title":"PipelineFlow.pipeline_mod/0","doc":"","ref":"PipelineFlow.html#t:pipeline_mod/0"},{"type":"type","title":"PipelineFlow.step/0","doc":"","ref":"PipelineFlow.html#t:step/0"},{"type":"module","title":"PipelineFlow.Helpers","doc":"Helpers module for PipelineFlow structs. All these functions are also imported when you use the PiplineFlow macro.","ref":"PipelineFlow.Helpers.html"},{"type":"function","title":"PipelineFlow.Helpers.add_warning/3","doc":"Adds a warning","ref":"PipelineFlow.Helpers.html#add_warning/3"},{"type":"function","title":"Examples - PipelineFlow.Helpers.add_warning/3","doc":"iex> pipeline = %TestPipeline{}\n    ...> pipeline.warnings\n    []\n    iex> pipeline = PipelineFlow.Helpers.add_warning(pipeline, :first_step, \"A warning\")\n    ...> pipeline.warnings\n    [{:first_step, \"A warning\"}]","ref":"PipelineFlow.Helpers.html#add_warning/3-examples"},{"type":"function","title":"PipelineFlow.Helpers.allows_exec?/1","doc":"","ref":"PipelineFlow.Helpers.html#allows_exec?/1"},{"type":"function","title":"PipelineFlow.Helpers.completed?/2","doc":"Tests if the given steps on the PiplineFlow struct are completed","ref":"PipelineFlow.Helpers.html#completed?/2"},{"type":"function","title":"Examples - PipelineFlow.Helpers.completed?/2","doc":"iex> PipelineFlow.Helpers.completed?(%TestPipeline{}, [:result_tuple_on_argument])\n    false\n\n    iex> PipelineFlow.Helpers.completed?(%TestPipeline{}, :result_tuple_on_argument)\n    false\n\n    iex> PipelineFlow.Helpers.completed?(%TestPipeline{completed_steps: [:result_tuple_on_argument]}, [:result_tuple_on_argument])\n    true\n\n    iex> PipelineFlow.Helpers.completed?(%TestPipeline{completed_steps: [:result_tuple_on_argument]}, :result_tuple_on_argument)\n    true","ref":"PipelineFlow.Helpers.html#completed?/2-examples"},{"type":"function","title":"PipelineFlow.Helpers.error?/1","doc":"Checks if PiplineFlow was executed correctly","ref":"PipelineFlow.Helpers.html#error?/1"},{"type":"function","title":"Examples - PipelineFlow.Helpers.error?/1","doc":"iex> PipelineFlow.Helpers.error?(%TestPipeline{error: :faulty})\n    true\n\n    iex> PipelineFlow.Helpers.error?(%TestPipeline{})\n    false","ref":"PipelineFlow.Helpers.html#error?/1-examples"},{"type":"function","title":"PipelineFlow.Helpers.exec/1","doc":"","ref":"PipelineFlow.Helpers.html#exec/1"},{"type":"function","title":"PipelineFlow.Helpers.get_attributes/1","doc":"Transforms PipelineFlow in map of attributes\n\niex> PipelineFlow.Helpers.get_attributes(%TestPipeline{some_attribute: \"foobar\", list_attribute: [\"1\", \"2\", \"3\"]})\n%{some_attribute: \"foobar\", list_attribute: [\"1\", \"2\", \"3\"]}","ref":"PipelineFlow.Helpers.html#get_attributes/1"},{"type":"function","title":"PipelineFlow.Helpers.halt/1","doc":"Halts execution of flow","ref":"PipelineFlow.Helpers.html#halt/1"},{"type":"function","title":"Examples - PipelineFlow.Helpers.halt/1","doc":"iex> pipeline = %TestPipeline{}\n    %TestPipeline{}\n    iex> pipeline = PipelineFlow.Helpers.halt(pipeline)\n    ...> PipelineFlow.Helpers.halted?(pipeline)\n    true","ref":"PipelineFlow.Helpers.html#halt/1-examples"},{"type":"function","title":"PipelineFlow.Helpers.halted?/1","doc":"Checks if the PipelineFlow has halted execution","ref":"PipelineFlow.Helpers.html#halted?/1"},{"type":"function","title":"Examples - PipelineFlow.Helpers.halted?/1","doc":"iex> PipelineFlow.Helpers.halted?(%TestPipeline{})\n    false\n\n    iex> PipelineFlow.Helpers.halted?(%TestPipeline{} |> PipelineFlow.Helpers.halt())\n    true","ref":"PipelineFlow.Helpers.html#halted?/1-examples"},{"type":"macro","title":"PipelineFlow.Helpers.is_pipeline/1","doc":"","ref":"PipelineFlow.Helpers.html#is_pipeline/1"},{"type":"macro","title":"PipelineFlow.Helpers.is_pipeline_module/1","doc":"","ref":"PipelineFlow.Helpers.html#is_pipeline_module/1"},{"type":"macro","title":"PipelineFlow.Helpers.is_step/1","doc":"","ref":"PipelineFlow.Helpers.html#is_step/1"},{"type":"function","title":"PipelineFlow.Helpers.log/1","doc":"Logs the state of a given PipelineFlow struct","ref":"PipelineFlow.Helpers.html#log/1"},{"type":"function","title":"PipelineFlow.Helpers.ok?/1","doc":"Checks if PiplineFlow was executed correctly","ref":"PipelineFlow.Helpers.html#ok?/1"},{"type":"function","title":"Examples - PipelineFlow.Helpers.ok?/1","doc":"iex> PipelineFlow.Helpers.ok?(%TestPipeline{})\n    true\n\n    iex> PipelineFlow.Helpers.ok?(%TestPipeline{error: :faulty})\n    false","ref":"PipelineFlow.Helpers.html#ok?/1-examples"},{"type":"function","title":"PipelineFlow.Helpers.result/1","doc":"Parses the result of a PiplineFlow struct. Returns `{:ok, any()}` when pipeline.\nDepending on the implementation of the PipelineFlow struct, the result will be that struct itself,\nthe value set in the struct or the value that is returned from the `value(PipelineFlow.t())` function\nthat is implemented on the module.\n\ndidn't encountered an error. Returns `{:error, atom(), any()}` (where `atom()` is the step where the error eccoured)","ref":"PipelineFlow.Helpers.html#result/1"},{"type":"function","title":"Examples - PipelineFlow.Helpers.result/1","doc":"iex> PipelineFlow.Helpers.result(%TestPipeline{})\n    {:ok, %TestPipeline{}}\n\n    iex> PipelineFlow.Helpers.result(%TestPipeline{value: \"some-value\"})\n    {:ok, \"some-value\"}\n\n    iex> PipelineFlow.Helpers.result(%TestPipeline2{some_attribute: \"value-returned-from-value-function\"})\n    {:ok, \"value-returned-from-value-function\"}\n\n    iex> PipelineFlow.Helpers.result(%TestPipeline{error: :faulty, last_step: :get_data})\n    {:error, :get_data, :faulty}","ref":"PipelineFlow.Helpers.html#result/1-examples"},{"type":"function","title":"PipelineFlow.Helpers.set_attribute/2","doc":"Sets attribute on PipelineFlow module struct","ref":"PipelineFlow.Helpers.html#set_attribute/2"},{"type":"function","title":"Examples - PipelineFlow.Helpers.set_attribute/2","doc":"iex> %TestPipeline{}\n    %TestPipeline{some_attribute: nil}\n\n    iex> PipelineFlow.Helpers.set_attribute(%TestPipeline{}, :some_attribute, \"foobar\")\n    %TestPipeline{some_attribute: \"foobar\"}\n\n    iex> PipelineFlow.Helpers.set_attribute(%TestPipeline{}, :non_existing_field, \"foobar\")\n    %TestPipeline{}\n\n    iex> PipelineFlow.Helpers.set_attribute(%TestPipeline{}, %{some_attribute: \"foobar\"})\n    %TestPipeline{some_attribute: \"foobar\"}\n\n    iex> PipelineFlow.Helpers.set_attribute(%TestPipeline{}, %{non_existing_field: \"foobar\"})\n    %TestPipeline{}","ref":"PipelineFlow.Helpers.html#set_attribute/2-examples"},{"type":"function","title":"PipelineFlow.Helpers.set_attribute/3","doc":"","ref":"PipelineFlow.Helpers.html#set_attribute/3"},{"type":"function","title":"PipelineFlow.Helpers.set_completed_step/2","doc":"Adds completed step to list","ref":"PipelineFlow.Helpers.html#set_completed_step/2"},{"type":"function","title":"Examples - PipelineFlow.Helpers.set_completed_step/2","doc":"iex> pipeline = %TestPipeline{}\n    ...> pipeline.completed_steps\n    []\n    iex> pipeline = PipelineFlow.Helpers.set_completed_step(pipeline, :result_tuple_on_argument)\n    ...> pipeline.completed_steps\n    [:result_tuple_on_argument]\n    iex> pipeline = PipelineFlow.Helpers.set_completed_step(pipeline, :non_existing_step)\n    ...> pipeline.completed_steps\n    [:result_tuple_on_argument]","ref":"PipelineFlow.Helpers.html#set_completed_step/2-examples"},{"type":"function","title":"PipelineFlow.Helpers.set_error/2","doc":"Sets last encountered error of PipelineFlow struct","ref":"PipelineFlow.Helpers.html#set_error/2"},{"type":"function","title":"PipelineFlow.Helpers.set_last_step/2","doc":"Sets last performed step of PipelineFlow struct","ref":"PipelineFlow.Helpers.html#set_last_step/2"},{"type":"function","title":"Examples - PipelineFlow.Helpers.set_last_step/2","doc":"iex> PipelineFlow.Helpers.set_last_step(%TestPipeline{}, :result_tuple_pipeline_return_value)\n    %TestPipeline{last_step: :result_tuple_pipeline_return_value}\n\n    iex> PipelineFlow.Helpers.set_last_step(%TestPipeline{}, :step_does_not_exist)\n    %TestPipeline{}","ref":"PipelineFlow.Helpers.html#set_last_step/2-examples"},{"type":"function","title":"PipelineFlow.Helpers.set_parent/2","doc":"Sets a parent PipelineFlow to the child PipelineFlow. Can be used when\nyou are using a string of flows that are dependent of each other.","ref":"PipelineFlow.Helpers.html#set_parent/2"},{"type":"function","title":"Examples - PipelineFlow.Helpers.set_parent/2","doc":"iex> pipeline = %TestPipeline{}\n    ...> pipeline.parent\n    nil\n    iex> other_pipeline = %TestPipeline2{}\n    ...>\n    ...> PipelineFlow.Helpers.set_parent(pipeline, other_pipeline)\n    %TestPipeline{parent: %TestPipeline2{}}","ref":"PipelineFlow.Helpers.html#set_parent/2-examples"},{"type":"function","title":"PipelineFlow.Helpers.set_result/3","doc":"","ref":"PipelineFlow.Helpers.html#set_result/3"},{"type":"function","title":"PipelineFlow.Helpers.status/1","doc":"Returns the current status of a pipeline. Can be either be :ok, :error or :halt","ref":"PipelineFlow.Helpers.html#status/1"},{"type":"function","title":"Examples - PipelineFlow.Helpers.status/1","doc":"iex> PipelineFlow.Helpers.status(%TestPipeline{})\n    :ok\n    iex> PipelineFlow.Helpers.status(%TestPipeline{error: :faulty})\n    :error\n    iex> PipelineFlow.Helpers.status(%TestPipeline{halted: true})\n    :halt\n    iex> PipelineFlow.Helpers.status(%TestPipeline{error: :faulty, halted: true})\n    :halt","ref":"PipelineFlow.Helpers.html#status/1-examples"},{"type":"function","title":"PipelineFlow.Helpers.step_defined?/2","doc":"Tests if given step is defined on PipelineFlow struct","ref":"PipelineFlow.Helpers.html#step_defined?/2"},{"type":"function","title":"Examples - PipelineFlow.Helpers.step_defined?/2","doc":"iex> PipelineFlow.Helpers.step_defined?(TestPipeline, :get_products)\n    false\n\n    iex> PipelineFlow.Helpers.step_defined?(TestPipeline, :result_tuple_on_argument)\n    true","ref":"PipelineFlow.Helpers.html#step_defined?/2-examples"},{"type":"module","title":"PipelineFlow.MacroHelpers","doc":"","ref":"PipelineFlow.MacroHelpers.html"},{"type":"function","title":"PipelineFlow.MacroHelpers.check_required_steps!/2","doc":"","ref":"PipelineFlow.MacroHelpers.html#check_required_steps!/2"},{"type":"function","title":"PipelineFlow.MacroHelpers.find_steps_order!/1","doc":"","ref":"PipelineFlow.MacroHelpers.html#find_steps_order!/1"},{"type":"exception","title":"PipelineFlow.Error","doc":"","ref":"PipelineFlow.Error.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}